'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-0e20a87a.js');
const defaultIconPack = require('./default-icon-pack-d94ddba8.js');
const string = require('./string-d17dee1d.js');
const floatingUi_dom_esm = require('./floating-ui.dom.esm-ee3bfb57.js');
const index$1 = require('./index-211dabb8.js');

const getInitials = (name) => {
  return name
    .split(' ')
    .map((part) => part[0])
    .join('')
    .toUpperCase();
};

const dyteAvatarCss = ":host{display:flex;height:var(--dyte-space-20, 80px);width:var(--dyte-space-20, 80px);align-items:center;justify-content:center;font-family:var(--dyte-font-family, sans-serif);font-size:28px;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-video-bg, 24 24 24) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-1000, 255 255 255));overflow:hidden;border-radius:9999px}dyte-icon{height:50%;width:50%}.initials{display:flex;height:100%;width:100%;align-items:center;justify-content:center;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-brand-500, 33 96 253) / var(--tw-bg-opacity))}.image{display:flex;height:100%;width:100%;align-items:center;justify-content:center}.image img{display:none;height:100%;width:100%;-o-object-fit:cover;object-fit:cover}.image img.loaded{display:block}:host([type='hexagon']){border-radius:var(--dyte-border-radius-none, 0);-webkit-clip-path:polygon(50% 0, 95% 25%, 95% 75%, 50% 100%, 5% 75%, 5% 25%);clip-path:polygon(50% 0, 95% 25%, 95% 75%, 50% 100%, 5% 75%, 5% 25%)}:host([size='sm']){height:var(--dyte-space-12, 48px);width:var(--dyte-space-12, 48px);font-size:20px}:host([size='md']){height:var(--dyte-space-16, 64px);width:var(--dyte-space-16, 64px)}:host([size='lg']){height:var(--dyte-space-24, 96px);width:var(--dyte-space-24, 96px)}";

const DyteAvatar = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /** Avatar type */
    this.type = 'circular';
    /** Icon pack */
    this.iconPack = defaultIconPack.defaultIconPack;
  }
  render() {
    const name = string.formatName(this.peer.name);
    const initials = getInitials(name);
    return (index.h(index.Host, null, index.h("div", { class: "initials" }, initials)));
  }
};
DyteAvatar.style = dyteAvatarCss;

const dyteMenuCss = ":host{position:relative;display:inline-block}#menu-list{position:absolute;z-index:20;display:none}";

const DyteMenu = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.clickedThis = false;
    /** Placement of menu */
    this.placement = 'bottom-end';
    this.handleOutsideClick = () => {
      // handles clicking on other menu triggers
      if (!this.clickedThis) {
        // if other trigger is clicked, hide this menu-list
        this.menuListEl.style.display = 'none';
      }
      // reset the value
      this.clickedThis = false;
    };
  }
  connectedCallback() {
    document.addEventListener('click', this.handleOutsideClick);
  }
  componentDidLoad() {
    this.update();
  }
  disconnectedCallback() {
    document.removeEventListener('click', this.handleOutsideClick);
  }
  update() {
    floatingUi_dom_esm.computePosition(this.triggerEl, this.menuListEl, {
      placement: this.placement,
      middleware: [floatingUi_dom_esm.offset(6), floatingUi_dom_esm.flip(), floatingUi_dom_esm.shift({ padding: 5 })],
    }).then(({ x, y }) => {
      Object.assign(this.menuListEl.style, {
        left: `${x}px`,
        top: `${y}px`,
      });
    });
  }
  render() {
    return (index.h(index.Host, null, index.h("span", { id: "trigger", ref: (el) => (this.triggerEl = el), onClick: () => {
        this.clickedThis = true;
        if (this.menuListEl.style.display !== 'block') {
          this.menuListEl.style.display = 'block';
          this.update();
        }
        else {
          this.menuListEl.style.display = 'none';
        }
      } }, index.h("slot", { name: "trigger" })), index.h("span", { part: "menu-list", id: "menu-list", ref: (el) => (this.menuListEl = el) }, index.h("slot", null))));
  }
};
DyteMenu.style = dyteMenuCss;

const dyteMenuItemCss = ":host{display:flex;align-items:center;padding-left:var(--dyte-space-3, 12px);padding-right:var(--dyte-space-3, 12px);padding-top:var(--dyte-space-2, 8px);padding-bottom:var(--dyte-space-2, 8px);cursor:pointer;transition-property:color, background-color, border-color, fill, stroke, -webkit-text-decoration-color;transition-property:color, background-color, border-color, text-decoration-color, fill, stroke;transition-property:color, background-color, border-color, text-decoration-color, fill, stroke, -webkit-text-decoration-color;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}::slotted([slot='start']){margin-right:var(--dyte-space-2, 8px)}::slotted([slot='end']){margin-left:var(--dyte-space-2, 8px)}:host(:hover){--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-600, 60 60 60) / var(--tw-bg-opacity))}:host(.red){--tw-text-opacity:1;color:rgba(var(--dyte-colors-danger, 255 45 45) / var(--tw-text-opacity))}";

const DyteMenuItem = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
  }
  render() {
    return (index.h(index.Host, null, index.h("slot", { name: "start" }), index.h("slot", null), index.h("slot", { name: "end" })));
  }
};
DyteMenuItem.style = dyteMenuItemCss;

const dyteMenuListCss = ":host{display:flex;width:-webkit-max-content;width:-moz-max-content;width:max-content;flex-direction:column;padding-top:var(--dyte-space-2, 8px);padding-bottom:var(--dyte-space-2, 8px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-800, 30 30 30) / var(--tw-bg-opacity));overflow:hidden;border-radius:var(--dyte-border-radius-sm, 4px);--tw-shadow:0 10px 15px -3px rgb(0 0 0 / 0.1), 0 4px 6px -4px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 10px 15px -3px var(--tw-shadow-color), 0 4px 6px -4px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}";

const DyteMenuList = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
  }
  render() {
    return (index.h(index.Host, null, index.h("slot", null)));
  }
};
DyteMenuList.style = dyteMenuListCss;

const dyteParticipantCss = ":host{position:relative;display:flex;height:var(--dyte-space-14, 56px);align-items:center;justify-content:space-between}.left{display:flex;align-items:center}.left>*{margin-right:var(--dyte-space-2, 8px)}.left>*:last-child{margin-right:var(--dyte-space-0, 0px)}.right{display:flex;align-items:center;justify-content:flex-end}.right>*{margin-left:var(--dyte-space-2, 8px)}.right>*:first-child{margin-left:var(--dyte-space-0, 0px)}.name{overflow:hidden;display:-webkit-box;-webkit-box-orient:vertical;-webkit-line-clamp:1}dyte-avatar{height:var(--dyte-space-8, 32px);width:var(--dyte-space-8, 32px);font-size:14px}dyte-icon{height:var(--dyte-space-6, 24px);width:var(--dyte-space-6, 24px)}dyte-icon.red{--tw-text-opacity:1;color:rgba(var(--dyte-colors-danger, 255 45 45) / var(--tw-text-opacity))}dyte-icon.more{cursor:pointer}";

const DyteParticipant = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /** Icon pack */
    this.iconPack = defaultIconPack.defaultIconPack;
    /** Language */
    this.t = index$1.useLanguage();
    this.audioEnabled = false;
    this.videoEnabled = false;
    this.canDisableParticipantAudio = false;
    this.canDisableParticipantVideo = false;
    this.canKickParticipant = false;
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
    this.peerChanged(this.peer);
  }
  disconnectedCallback() {
    if (this.peer == null)
      return;
    this.audioUpdateListener && this.peer.removeListener('audioUpdate', this.audioUpdateListener);
    this.videoUpdateListener && this.peer.removeListener('videoUpdate', this.videoUpdateListener);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.canDisableParticipantAudio = meeting.self.permissions.canAllowParticipantAudio;
      this.canDisableParticipantVideo = meeting.self.permissions.canAllowParticipantVideo;
      this.canKickParticipant = meeting.self.permissions.kickParticipant;
    }
  }
  peerChanged(peer) {
    if (peer != null) {
      this.audioEnabled = peer.audioEnabled;
      this.videoEnabled = peer.videoEnabled;
      this.audioUpdateListener = ({ audioEnabled }) => {
        this.audioEnabled = audioEnabled;
      };
      this.videoUpdateListener = ({ videoEnabled }) => {
        this.videoEnabled = videoEnabled;
      };
      peer.addListener('audioUpdate', this.audioUpdateListener);
      peer.addListener('videoUpdate', this.videoUpdateListener);
    }
  }
  render() {
    const showMenu = this.canDisableParticipantAudio || this.canDisableParticipantVideo || this.canKickParticipant;
    const name = string.formatName(this.peer.name);
    return (index.h(index.Host, null, index.h("div", { class: "left" }, index.h("dyte-avatar", { peer: this.peer }), index.h("p", { class: "name", title: name }, string.shorten(name, 16), " ", this.meeting.self.id === this.peer.id && this.t('(you)'))), index.h("div", { class: "right" }, index.h("dyte-icon", { class: {
        red: !this.audioEnabled,
      }, icon: this.audioEnabled ? this.iconPack.mic_on : this.iconPack.mic_off }), index.h("dyte-icon", { class: {
        red: !this.videoEnabled,
      }, icon: this.videoEnabled ? this.iconPack.video_on : this.iconPack.video_off }), showMenu && (index.h("dyte-menu", null, index.h("dyte-button", { variant: "ghost", kind: "icon", slot: "trigger" }, index.h("dyte-icon", { class: "more", icon: this.iconPack.more_vertical })), index.h("dyte-menu-list", null, this.canDisableParticipantAudio && (index.h("dyte-menu-item", { onClick: () => {
        this.meeting.participants.disableAudio(this.peer.id);
      } }, index.h("dyte-icon", { icon: this.iconPack.mic_off, slot: "start" }), "Mute")), this.canDisableParticipantAudio && (index.h("dyte-menu-item", { onClick: () => {
        this.meeting.participants.disableVideo(this.peer.id);
      } }, index.h("dyte-icon", { icon: this.iconPack.video_off, slot: "start" }), "Turn off Video")), this.canKickParticipant && (index.h("dyte-menu-item", { class: "red", onClick: () => {
        this.meeting.participants.kick(this.peer.id);
      } }, index.h("dyte-icon", { icon: this.iconPack.dismiss, slot: "start" }), "Kick"))))))));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"],
    "peer": ["peerChanged"]
  }; }
};
DyteParticipant.style = dyteParticipantCss;

exports.dyte_avatar = DyteAvatar;
exports.dyte_menu = DyteMenu;
exports.dyte_menu_item = DyteMenuItem;
exports.dyte_menu_list = DyteMenuList;
exports.dyte_participant = DyteParticipant;
