'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-0e20a87a.js');
const defaultIconPack = require('./default-icon-pack-d94ddba8.js');

const dytePeerViewCss = ":host{position:relative;display:flex;align-items:center;justify-content:center;font-family:var(--dyte-font-family, sans-serif);aspect-ratio:16 / 9;height:var(--dyte-space-56, 224px);overflow:hidden;border-radius:var(--dyte-border-radius-lg, 12px);-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-video-bg, 24 24 24) / var(--tw-bg-opacity));transition:flex-grow 0.4s}::slotted(dyte-name-tag){position:absolute;left:var(--dyte-space-3, 12px);bottom:var(--dyte-space-3, 12px)}:host([size='sm'][variant='solid']) ::slotted(dyte-name-tag){left:var(--dyte-space-2, 8px);bottom:var(--dyte-space-2, 8px);height:var(--dyte-space-4, 16px)}video{display:none;position:absolute;height:100%;width:100%;border-radius:var(--dyte-border-radius-lg, 12px);-o-object-fit:cover;object-fit:cover}video.visible{display:block}video::-webkit-media-controls{display:none !important}:host([variant='gradient']) ::slotted(dyte-audio-visualizer){position:absolute;top:var(--dyte-space-2, 8px);right:var(--dyte-space-2, 8px);border-radius:9999px;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-brand-500, 33 96 253) / var(--tw-bg-opacity));padding:var(--dyte-space-2, 8px)}:host([variant='gradient']) ::slotted(dyte-name-tag){bottom:var(--dyte-space-0, 0px);left:var(--dyte-space-0, 0px);display:flex;width:100%;align-items:center;justify-content:center;text-align:center;background-color:transparent;background-image:linear-gradient(to top, var(--tw-gradient-stops));--tw-gradient-from:rgb(var(--dyte-colors-background-1000, 8 8 8));--tw-gradient-stops:var(--tw-gradient-from), var(--tw-gradient-to, rgba(var(--dyte-colors-background-1000, 8 8 8) / 0));--tw-gradient-to:transparent}video.mirror{transform:scaleX(-1)}:host([name-tag-position='bottom-right']) ::slotted(dyte-name-tag){left:auto;right:var(--dyte-space-3, 12px)}:host([name-tag-position='bottom-center']) ::slotted(dyte-name-tag){left:auto;right:auto}:host([name-tag-position='top-left']) ::slotted(dyte-name-tag){top:var(--dyte-space-3, 12px);bottom:auto}:host([name-tag-position='top-right']) ::slotted(dyte-name-tag){top:var(--dyte-space-3, 12px);right:var(--dyte-space-3, 12px);left:auto;bottom:auto}:host([name-tag-position='top-center']) ::slotted(dyte-name-tag){left:auto;right:auto;bottom:auto;top:var(--dyte-space-3, 12px)}";

const PeerView = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.isSelf = false;
    /** Position of name tag */
    this.nameTagPosition = 'bottom-left';
    /** Variant */
    this.variant = 'solid';
    /** Icon pack */
    this.iconPack = defaultIconPack.defaultIconPack;
    /** Is preview */
    this.isPreview = false;
    this.videoEnabled = false;
    this.isMirrored = false;
  }
  componentDidLoad() {
    this.peerChanged(this.peer);
  }
  disconnectedCallback() {
    var _a, _b;
    this.previewUpdateListener &&
      ((_a = this.peer) === null || _a === void 0 ? void 0 : _a.removeListener('previewUpdate', this.previewUpdateListener));
    this.videoUpdateListener && ((_b = this.peer) === null || _b === void 0 ? void 0 : _b.removeListener('videoUpdate', this.videoUpdateListener));
  }
  peerChanged(peer) {
    if (peer != null) {
      if ('preview' in peer || this.isPreview) {
        // initial values
        index.writeTask(() => {
          var _a, _b, _c;
          this.isSelf = true;
          this.isMirrored = (_c = (_b = (_a = this.states) === null || _a === void 0 ? void 0 : _a.prefs) === null || _b === void 0 ? void 0 : _b.mirrorVideo) !== null && _c !== void 0 ? _c : false;
        });
      }
      this.videoUpdateListener = ({ videoEnabled, videoTrack }) => {
        index.writeTask(() => {
          this.videoEnabled = videoEnabled && videoTrack != null;
        });
        if (videoEnabled && videoTrack != null) {
          const stream = new MediaStream();
          stream.addTrack(videoTrack);
          if (this.videoEl != null) {
            this.videoEl.srcObject = stream;
          }
        }
        else {
          this.videoEl.srcObject = undefined;
        }
      };
      if (this.isPreview) {
        this.previewUpdateListener = ({ preview }) => {
          const { videoEnabled, videoTrack } = preview;
          this.videoUpdateListener({ videoEnabled, videoTrack });
        };
        this.previewUpdateListener(peer);
        peer.addListener('previewUpdate', this.previewUpdateListener);
      }
      else {
        this.videoUpdateListener(peer);
      }
      peer.addListener('videoUpdate', this.videoUpdateListener);
    }
  }
  statesChanged(states) {
    if (this.isSelf && states.prefs != null && 'mirrorVideo' in states.prefs) {
      this.isMirrored = states.prefs.mirrorVideo;
    }
  }
  render() {
    return (index.h(index.Host, null, index.h("video", { ref: (el) => (this.videoEl = el), class: {
        visible: this.videoEnabled,
        mirror: this.isMirrored,
      }, autoPlay: true, playsInline: true, muted: true }), index.h("slot", null)));
  }
  static get watchers() { return {
    "peer": ["peerChanged"],
    "states": ["statesChanged"]
  }; }
};
PeerView.style = dytePeerViewCss;

exports.dyte_peer_view = PeerView;
