import { Component, Host, h, Prop, Event } from '@stencil/core';
import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
import { downloadFile } from '../../utils/file';
import { formatName, shorten } from '../../utils/string';
export class DyteImageViewer {
  constructor() {
    /** Language */
    this.t = useLanguage();
    /** Icon pack */
    this.iconPack = defaultIconPack;
    this.keypressListener = (e) => {
      if (e.key === 'Escape') {
        this.close.emit();
      }
    };
    this.handleOutsideClick = () => this.close.emit();
  }
  connectedCallback() {
    document.addEventListener('keydown', this.keypressListener);
    document.addEventListener('click', this.handleOutsideClick);
  }
  disconnectedCallback() {
    document.removeEventListener('keydown', this.keypressListener);
    document.removeEventListener('click', this.handleOutsideClick);
  }
  render() {
    return (h(Host, { class: "scrollbar" },
      h("div", { class: "modal", onClick: (e) => e.stopPropagation() },
        h("div", { class: "modal-header" },
          h("div", { class: "shared-by-user" },
            this.t('Shared by'),
            ' ',
            h("span", { class: "displayName" }, formatName(shorten(this.image.displayName)))),
          h("div", { class: "actions" },
            h("dyte-button", { kind: "icon", variant: "neutral", onClick: () => this.close.emit() },
              h("dyte-icon", { icon: this.iconPack.arrow_minimize })),
            h("dyte-button", { onClick: () => downloadFile(this.image.link, { fallbackName: 'image' }) },
              h("dyte-icon", { icon: this.iconPack.download, slot: "start" }),
              "Download"))),
        h("div", { class: "image-ctr" },
          h("img", { src: this.image.link })))));
  }
  static get is() { return "dyte-image-viewer"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-image-viewer.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-image-viewer.css"]
  }; }
  static get properties() { return {
    "image": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "ImageMessage",
        "resolved": "ImageMessage",
        "references": {
          "ImageMessage": {
            "location": "import",
            "path": "@dyte-in/client-core/types/client/DyteChat"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Image message"
      }
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ live: string; people: string; chat: string; poll: string; participants: string; rocket: string; video_background_effect: string; call_end: string; grid: string; share: string; check_mark: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; speaker_off: string; avatar: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; arrow_expand: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; arrow_minimize: string; image_off: string; disconnected: string; poor_network: string; wand: string; rejoin: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    }
  }; }
  static get events() { return [{
      "method": "close",
      "name": "close",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emitted when viewer should be closed"
      },
      "complexType": {
        "original": "void",
        "resolved": "void",
        "references": {}
      }
    }]; }
}
