import { Component, Host, h, Prop, State, Watch, Event } from '@stencil/core';
import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
export class DyteSettings {
  constructor() {
    this.keyPressListener = (e) => {
      if (e.key === 'Escape') {
        this.close();
      }
    };
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.activeTab = 'connection';
    this.isMobileMainVisible = false;
    this.networkStatus = 'good';
    this.canProduceAudio = false;
    this.canProduceVideo = false;
  }
  connectedCallback() {
    document.addEventListener('keydown', this.keyPressListener);
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    var _a, _b;
    (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.disablePreview();
    this.keyPressListener && document.removeEventListener('keydown', this.keyPressListener);
    this.poorConnectionListener &&
      ((_b = this.meeting) === null || _b === void 0 ? void 0 : _b.meta.removeListener('poorConnection', this.poorConnectionListener));
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.canProduceAudio = meeting.self.permissions.produceAudio;
      this.canProduceVideo = meeting.self.permissions.produceVideo.allow;
      if (!this.canProduceAudio && !this.canProduceVideo) {
        // don't show anything
        this.activeTab = 'connection';
      }
      else if (this.canProduceAudio) {
        this.activeTab = 'audio';
      }
      else {
        this.activeTab = 'video';
      }
      this.poorConnectionListener = ({ score }) => {
        if (score < 7) {
          this.networkStatus = 'poor';
        }
        else if (score < 4) {
          this.networkStatus = 'poorest';
        }
        setTimeout(() => {
          // reset after 5 seconds
          this.networkStatus = 'good';
        }, 5000);
      };
      this.meeting.meta.addListener('poorConnection', this.poorConnectionListener);
    }
  }
  changeTab(tab) {
    this.activeTab = tab;
    if (this.size === 'sm') {
      if (!this.isMobileMainVisible) {
        this.isMobileMainVisible = true;
      }
    }
  }
  close() {
    this.stateUpdate.emit({ activeSettings: false });
  }
  render() {
    if (this.meeting == null)
      return null;
    const defaults = {
      meeting: this.meeting,
      states: this.states,
      iconPack: this.iconPack,
      t: this.t,
    };
    return (h(Host, null,
      h("dyte-button", { kind: "icon", class: "dismiss-btn", onClick: () => this.close() },
        h("dyte-icon", { icon: this.iconPack.dismiss })),
      h("aside", { class: { hide: this.isMobileMainVisible } },
        h("header", null,
          h("h2", null, this.t('settings'))),
        this.canProduceAudio && (h("button", { type: "button", class: { active: this.activeTab === 'audio' }, onClick: () => this.changeTab('audio') },
          this.t('audio'),
          h("div", { class: "right" },
            h("dyte-icon", { icon: this.iconPack.mic_on }),
            this.size === 'sm' && h("dyte-icon", { icon: this.iconPack.chevron_right })))),
        this.canProduceVideo && (h("button", { type: "button", class: { active: this.activeTab === 'video' }, onClick: () => this.changeTab('video') },
          this.t('video'),
          h("div", { class: "right" },
            h("dyte-icon", { icon: this.iconPack.video_on }),
            this.size === 'sm' && h("dyte-icon", { icon: this.iconPack.chevron_right })))),
        h("button", { type: "none", title: `Your network condition is ${this.networkStatus}` },
          this.t('connection'),
          h("div", { class: "right" },
            h("dyte-icon", { icon: this.iconPack.wifi, class: this.networkStatus })))),
      h("main", { class: { active: this.isMobileMainVisible } },
        this.size === 'sm' && (h("header", null,
          h("dyte-button", { kind: "icon", class: "back-btn", onClick: () => (this.isMobileMainVisible = false) },
            h("dyte-icon", { icon: this.iconPack.chevron_left })),
          h("h2", null, this.t(this.activeTab === 'audio' ? 'audio' : 'video')))),
        this.activeTab === 'audio' && h("dyte-settings-audio", Object.assign({}, defaults)),
        this.activeTab === 'video' && h("dyte-settings-video", Object.assign({}, defaults)))));
  }
  static get is() { return "dyte-settings"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-settings.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-settings.css"]
  }; }
  static get properties() { return {
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting object"
      }
    },
    "states": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "States",
        "resolved": "States",
        "references": {
          "States": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "States object"
      }
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ live: string; people: string; chat: string; poll: string; participants: string; rocket: string; video_background_effect: string; call_end: string; grid: string; share: string; check_mark: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; speaker_off: string; avatar: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; arrow_expand: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; arrow_minimize: string; image_off: string; disconnected: string; poor_network: string; wand: string; rejoin: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "activeTab": {},
    "isMobileMainVisible": {},
    "networkStatus": {},
    "canProduceAudio": {},
    "canProduceVideo": {}
  }; }
  static get events() { return [{
      "method": "stateUpdate",
      "name": "dyteStateUpdate",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Update global state"
      },
      "complexType": {
        "original": "States",
        "resolved": "States",
        "references": {
          "States": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      }
    }]; }
  static get watchers() { return [{
      "propName": "meeting",
      "methodName": "meetingChanged"
    }]; }
}
