import { Component, Host, h, State, Prop, Watch, Event } from '@stencil/core';
import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
export class DyteSidebar {
  constructor() {
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    /** View type */
    this.view = 'default';
    this.tab = 'none';
  }
  connectedCallback() {
    this.viewChanged(this.view);
    this.statesChanged(this.states);
  }
  disconnectedCallback() {
    this.keydownListener && document.removeEventListener('keydown', this.keydownListener);
  }
  statesChanged(states) {
    if (states != null) {
      if (states.sidebar) {
        this.tab = states.sidebar;
      }
    }
  }
  viewChanged(view) {
    if (view === 'full-screen') {
      this.keydownListener = (e) => {
        if (e.key === 'Escape') {
          this.close();
        }
      };
      document.addEventListener('keydown', this.keydownListener);
    }
  }
  close() {
    this.stateUpdate.emit({ activeSidebar: false, sidebar: 'none' });
  }
  render() {
    const defaults = { meeting: this.meeting, size: this.size, config: this.config };
    return (h(Host, { style: { display: this.tab === 'none' ? 'none' : undefined } },
      this.view === 'full-screen' && [
        h("h3", { class: "title" }, this.t('About Call')),
        h("div", { id: "mobile-header" },
          h("dyte-button", { variant: "neutral", class: { active: this.tab === 'chat' }, onClick: () => {
              this.stateUpdate.emit({ sidebar: 'chat' });
            } }, "Chat"),
          h("dyte-button", { variant: "neutral", class: { active: this.tab === 'participants' }, onClick: () => {
              this.stateUpdate.emit({ sidebar: 'participants' });
            } }, "Participants"),
          h("dyte-button", { variant: "neutral", class: { active: this.tab === 'plugins' }, onClick: () => {
              this.stateUpdate.emit({ sidebar: 'plugins' });
            } }, "Plugins")),
      ],
      h("dyte-button", { variant: "ghost", kind: "icon", class: "close", onClick: () => this.close(), "aria-label": this.t('Close') },
        h("dyte-icon", { icon: this.iconPack.dismiss })),
      this.view !== 'full-screen' && h("h3", { class: "title" }, this.t(this.tab)),
      this.tab === 'chat' && h("dyte-chat", Object.assign({}, defaults)),
      this.tab === 'participants' && h("dyte-participants", Object.assign({}, defaults)),
      this.tab === 'plugins' && h("dyte-plugins", Object.assign({}, defaults))));
  }
  static get is() { return "dyte-sidebar"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-sidebar.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-sidebar.css"]
  }; }
  static get properties() { return {
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting object"
      }
    },
    "states": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "States",
        "resolved": "States",
        "references": {
          "States": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "States object"
      }
    },
    "config": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "UIConfig",
        "resolved": "UIConfig",
        "references": {
          "UIConfig": {
            "location": "import",
            "path": "../../types/ui-config"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Config"
      }
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ live: string; people: string; chat: string; poll: string; participants: string; rocket: string; video_background_effect: string; call_end: string; grid: string; share: string; check_mark: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; speaker_off: string; avatar: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; arrow_expand: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; arrow_minimize: string; image_off: string; disconnected: string; poor_network: string; wand: string; rejoin: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "view": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "SidebarView",
        "resolved": "\"default\" | \"full-screen\" | \"sidebar\"",
        "references": {
          "SidebarView": {
            "location": "local"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "View type"
      },
      "attribute": "view",
      "reflect": true,
      "defaultValue": "'default'"
    }
  }; }
  static get states() { return {
    "tab": {}
  }; }
  static get events() { return [{
      "method": "stateUpdate",
      "name": "dyteStateUpdate",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emits updated state data"
      },
      "complexType": {
        "original": "States",
        "resolved": "States",
        "references": {
          "States": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      }
    }]; }
  static get watchers() { return [{
      "propName": "states",
      "methodName": "statesChanged"
    }, {
      "propName": "view",
      "methodName": "viewChanged"
    }]; }
}
