import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { d as defaultIconPack } from './default-icon-pack.js';
import { u as useLanguage } from './index2.js';
import { d as downloadFile } from './file.js';
import { f as formatName, a as shorten } from './string.js';
import { d as defineCustomElement$2 } from './dyte-button2.js';
import { d as defineCustomElement$1 } from './dyte-icon2.js';

const dyteImageViewerCss = ".scrollbar{scrollbar-width:thin;scrollbar-color:var(--dyte-scrollbar-color, rgb(var(--dyte-colors-background-600, 60 60 60)))\n    var(--dyte-scrollbar-background, transparent)}.scrollbar::-webkit-scrollbar{height:var(--dyte-space-1\\.5, 6px);width:var(--dyte-space-1\\.5, 6px);border-radius:9999px;background-color:var(--dyte-scrollbar-background, transparent)}.scrollbar::-webkit-scrollbar-thumb{border-radius:9999px;background-color:var(--dyte-scrollbar-color, rgb(var(--dyte-colors-background-600, 60 60 60)))}:host{position:fixed;top:var(--dyte-space-0, 0px);right:var(--dyte-space-0, 0px);bottom:var(--dyte-space-0, 0px);left:var(--dyte-space-0, 0px);box-sizing:border-box;display:flex;align-items:center;justify-content:center;padding:var(--dyte-space-6, 24px);overflow-y:auto;background-color:rgba(var(--dyte-colors-background-1000, 8 8 8) / 0.8);z-index:40}.modal{box-sizing:border-box;display:flex;flex-direction:column;padding:var(--dyte-space-6, 24px);padding-top:var(--dyte-space-5, 20px);width:100%;max-width:940px;border-radius:var(--dyte-border-radius-md, 8px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-900, 26 26 26) / var(--tw-bg-opacity));margin-top:auto;margin-bottom:auto}.displayName{font-weight:700}.modal .image-ctr{margin-top:var(--dyte-space-2, 8px);box-sizing:border-box;display:flex;justify-content:center}.modal img{box-sizing:border-box;display:block;max-height:100%;max-width:100%}.modal-header{display:flex;align-items:center;justify-content:space-between;padding-bottom:var(--dyte-space-4, 16px)}dyte-button{height:var(--dyte-space-8, 32px);border-radius:var(--dyte-border-radius-sm, 4px)}dyte-button:last-child{margin-left:var(--dyte-space-2, 8px)}dyte-button{font-size:14px}dyte-button dyte-icon{width:var(--dyte-space-5, 20px)}.shared-by-user{overflow:hidden;display:-webkit-box;-webkit-box-orient:vertical;-webkit-line-clamp:1}:host([size='sm']) .modal-header{flex-direction:column}:host([size='sm']) .modal-header .actions{margin-top:var(--dyte-space-4, 16px)}";

const DyteImageViewer = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.close = createEvent(this, "close", 7);
    /** Language */
    this.t = useLanguage();
    /** Icon pack */
    this.iconPack = defaultIconPack;
    this.keypressListener = (e) => {
      if (e.key === 'Escape') {
        this.close.emit();
      }
    };
    this.handleOutsideClick = () => this.close.emit();
  }
  connectedCallback() {
    document.addEventListener('keydown', this.keypressListener);
    document.addEventListener('click', this.handleOutsideClick);
  }
  disconnectedCallback() {
    document.removeEventListener('keydown', this.keypressListener);
    document.removeEventListener('click', this.handleOutsideClick);
  }
  render() {
    return (h(Host, { class: "scrollbar" }, h("div", { class: "modal", onClick: (e) => e.stopPropagation() }, h("div", { class: "modal-header" }, h("div", { class: "shared-by-user" }, this.t('Shared by'), ' ', h("span", { class: "displayName" }, formatName(shorten(this.image.displayName)))), h("div", { class: "actions" }, h("dyte-button", { kind: "icon", variant: "neutral", onClick: () => this.close.emit() }, h("dyte-icon", { icon: this.iconPack.arrow_minimize })), h("dyte-button", { onClick: () => downloadFile(this.image.link, { fallbackName: 'image' }) }, h("dyte-icon", { icon: this.iconPack.download, slot: "start" }), "Download"))), h("div", { class: "image-ctr" }, h("img", { src: this.image.link })))));
  }
  static get style() { return dyteImageViewerCss; }
}, [1, "dyte-image-viewer", {
    "image": [16],
    "size": [513],
    "t": [16],
    "iconPack": [16]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-image-viewer", "dyte-button", "dyte-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-image-viewer":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteImageViewer);
      }
      break;
    case "dyte-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "dyte-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { DyteImageViewer as D, defineCustomElement as d };
