import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { u as useLanguage } from './index2.js';
import { d as defaultIconPack } from './default-icon-pack.js';
import { d as defineCustomElement$3 } from './dyte-button2.js';
import { d as defineCustomElement$2 } from './dyte-icon2.js';

const dyteLeaveMeetingCss = ".leave-modal{position:relative;display:flex;flex-direction:column;border-radius:var(--dyte-border-radius-md, 8px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-900, 26 26 26) / var(--tw-bg-opacity));padding:var(--dyte-space-4, 16px)}.leave-modal .header h2{margin:var(--dyte-space-0, 0px)}.leave-modal .content{font-size:14px}.leave-message p{margin-top:var(--dyte-space-3, 12px);margin-bottom:var(--dyte-space-3, 12px)}.leave-meeting{display:flex;flex-direction:row;justify-content:space-between}.leave-meeting dyte-button{width:100%}.leave-meeting dyte-button:last-child{margin-left:var(--dyte-space-2, 8px)}.leave-meeting-btn{--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-danger, 255 45 45) / var(--tw-bg-opacity))}.end-meeting{margin-top:var(--dyte-space-3, 12px);display:flex;flex-direction:row}.end-meeting .end-meeting-btn{flex-grow:1;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-danger, 255 45 45) / var(--tw-bg-opacity))}dyte-button{border-radius:var(--dyte-border-radius-sm, 4px)}dyte-button.dismiss{position:absolute;top:var(--dyte-space-3, 12px);right:var(--dyte-space-3, 12px);background-color:transparent;--tw-shadow:0 0 #0000;--tw-shadow-colored:0 0 #0000;box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}dyte-button.dismiss:hover{color:rgb(var(--dyte-colors-text-700, 255 255 255 / 0.64))}dyte-button.cancel{--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-700, 44 44 44) / var(--tw-bg-opacity))}dyte-button:hover{--tw-bg-opacity:0.6}";

const DyteLeaveMeeting$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.stateUpdate = createEvent(this, "dyteStateUpdate", 7);
    this.keyPressListener = (e) => {
      if (e.key === 'Escape') {
        this.close();
      }
    };
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.canEndMeeting = false;
    this.close = () => {
      this.stateUpdate.emit({ activeLeaveConfirmation: false });
    };
    this.handleLeave = () => {
      var _a;
      (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.leaveRoom();
    };
    this.handleEndMeeting = () => {
      var _a;
      (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.participants.kickAll();
    };
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
    document.addEventListener('keydown', this.keyPressListener);
  }
  componentDidLoad() { }
  disconnectedCallback() {
    document.removeEventListener('keydown', this.keyPressListener);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.canEndMeeting = meeting.self.permissions.kickParticipant;
    }
  }
  render() {
    return (h(Host, null, h("div", { class: "leave-modal" }, h("div", { class: "header" }, h("h2", { class: "title" }, this.t('leave')), h("dyte-button", { kind: "icon", class: "dismiss", title: this.t('Close'), onClick: () => this.close() }, h("dyte-icon", { icon: this.iconPack.dismiss }))), h("p", { class: "message" }, this.t('leave_confirmation')), h("div", { class: "content" }, h("div", { class: "leave-meeting" }, h("dyte-button", { class: "cancel", title: this.t('Close'), onClick: this.close }, this.t('cancel')), h("dyte-button", { class: "leave-meeting-btn", title: this.t('leave'), onClick: this.handleLeave }, this.t('leave'))), this.canEndMeeting && (h("div", { class: "end-meeting" }, h("dyte-button", { class: "end-meeting-btn", onClick: this.handleEndMeeting }, this.t('end_meeting_for_all'))))))));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
  static get style() { return dyteLeaveMeetingCss; }
}, [1, "dyte-leave-meeting", {
    "meeting": [16],
    "states": [16],
    "iconPack": [16],
    "t": [16],
    "canEndMeeting": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-leave-meeting", "dyte-button", "dyte-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-leave-meeting":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteLeaveMeeting$1);
      }
      break;
    case "dyte-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "dyte-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const DyteLeaveMeeting = DyteLeaveMeeting$1;
const defineCustomElement = defineCustomElement$1;

export { DyteLeaveMeeting, defineCustomElement };
