import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { d as defaultIconPack } from './default-icon-pack.js';
import { u as useLanguage } from './index2.js';
import { d as defineCustomElement$2 } from './dyte-controlbar-button2.js';
import { d as defineCustomElement$1 } from './dyte-icon2.js';

const dyteMicToggleCss = ":host{display:block;font-family:var(--dyte-font-family, sans-serif)}:host(.audioDisabled) :slotted(dyte-icon){--tw-text-opacity:1;color:rgba(var(--dyte-colors-danger, 255 45 45) / var(--tw-text-opacity))}";

const DyteMicToggle = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.audioEnabled = false;
    this.canProduceAudio = false;
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    var _a;
    this.audioUpdateListener &&
      ((_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.removeListener('audioUpdate', this.audioUpdateListener));
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      const self = meeting.self;
      this.canProduceAudio = self.permissions.produceAudio;
      this.audioEnabled = self.audioEnabled;
      this.audioUpdateListener = ({ audioEnabled }) => {
        this.audioEnabled = audioEnabled;
      };
      self.addListener('audioUpdate', this.audioUpdateListener);
    }
  }
  toggleMic() {
    var _a;
    const self = (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self;
    if (self == null || !this.canProduceAudio) {
      return;
    }
    if (self.audioEnabled) {
      self.disableAudio();
    }
    else {
      self.enableAudio();
    }
  }
  render() {
    if (!this.canProduceAudio) {
      return null;
    }
    const text = this.t(this.audioEnabled ? 'mic_on' : 'mic_off');
    return (h(Host, { title: text }, h("dyte-controlbar-button", { size: this.size, class: {
        'red-icon': !this.audioEnabled,
      }, onClick: () => this.toggleMic(), icon: this.audioEnabled ? this.iconPack.mic_on : this.iconPack.mic_off, label: text })));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
  static get style() { return dyteMicToggleCss; }
}, [1, "dyte-mic-toggle", {
    "meeting": [16],
    "size": [513],
    "iconPack": [16],
    "t": [16],
    "audioEnabled": [32],
    "canProduceAudio": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-mic-toggle", "dyte-controlbar-button", "dyte-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-mic-toggle":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteMicToggle);
      }
      break;
    case "dyte-controlbar-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "dyte-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { DyteMicToggle as D, defineCustomElement as d };
