import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { d as defaultIconPack } from './default-icon-pack.js';
import { u as useLanguage } from './index2.js';
import { f as formatName, a as shorten } from './string.js';
import { d as defineCustomElement$6 } from './dyte-avatar2.js';
import { d as defineCustomElement$5 } from './dyte-button2.js';
import { d as defineCustomElement$4 } from './dyte-icon2.js';
import { d as defineCustomElement$3 } from './dyte-menu2.js';
import { d as defineCustomElement$2 } from './dyte-menu-item2.js';
import { d as defineCustomElement$1 } from './dyte-menu-list2.js';

const dyteParticipantCss = ":host{position:relative;display:flex;height:var(--dyte-space-14, 56px);align-items:center;justify-content:space-between}.left{display:flex;align-items:center}.left>*{margin-right:var(--dyte-space-2, 8px)}.left>*:last-child{margin-right:var(--dyte-space-0, 0px)}.right{display:flex;align-items:center;justify-content:flex-end}.right>*{margin-left:var(--dyte-space-2, 8px)}.right>*:first-child{margin-left:var(--dyte-space-0, 0px)}.name{overflow:hidden;display:-webkit-box;-webkit-box-orient:vertical;-webkit-line-clamp:1}dyte-avatar{height:var(--dyte-space-8, 32px);width:var(--dyte-space-8, 32px);font-size:14px}dyte-icon{height:var(--dyte-space-6, 24px);width:var(--dyte-space-6, 24px)}dyte-icon.red{--tw-text-opacity:1;color:rgba(var(--dyte-colors-danger, 255 45 45) / var(--tw-text-opacity))}dyte-icon.more{cursor:pointer}";

const DyteParticipant = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.audioEnabled = false;
    this.videoEnabled = false;
    this.canDisableParticipantAudio = false;
    this.canDisableParticipantVideo = false;
    this.canKickParticipant = false;
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
    this.peerChanged(this.peer);
  }
  disconnectedCallback() {
    if (this.peer == null)
      return;
    this.audioUpdateListener && this.peer.removeListener('audioUpdate', this.audioUpdateListener);
    this.videoUpdateListener && this.peer.removeListener('videoUpdate', this.videoUpdateListener);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.canDisableParticipantAudio = meeting.self.permissions.canAllowParticipantAudio;
      this.canDisableParticipantVideo = meeting.self.permissions.canAllowParticipantVideo;
      this.canKickParticipant = meeting.self.permissions.kickParticipant;
    }
  }
  peerChanged(peer) {
    if (peer != null) {
      this.audioEnabled = peer.audioEnabled;
      this.videoEnabled = peer.videoEnabled;
      this.audioUpdateListener = ({ audioEnabled }) => {
        this.audioEnabled = audioEnabled;
      };
      this.videoUpdateListener = ({ videoEnabled }) => {
        this.videoEnabled = videoEnabled;
      };
      peer.addListener('audioUpdate', this.audioUpdateListener);
      peer.addListener('videoUpdate', this.videoUpdateListener);
    }
  }
  render() {
    const showMenu = this.canDisableParticipantAudio || this.canDisableParticipantVideo || this.canKickParticipant;
    const name = formatName(this.peer.name);
    return (h(Host, null, h("div", { class: "left" }, h("dyte-avatar", { peer: this.peer }), h("p", { class: "name", title: name }, shorten(name, 16), " ", this.meeting.self.id === this.peer.id && this.t('(you)'))), h("div", { class: "right" }, h("dyte-icon", { class: {
        red: !this.audioEnabled,
      }, icon: this.audioEnabled ? this.iconPack.mic_on : this.iconPack.mic_off }), h("dyte-icon", { class: {
        red: !this.videoEnabled,
      }, icon: this.videoEnabled ? this.iconPack.video_on : this.iconPack.video_off }), showMenu && (h("dyte-menu", null, h("dyte-button", { variant: "ghost", kind: "icon", slot: "trigger" }, h("dyte-icon", { class: "more", icon: this.iconPack.more_vertical })), h("dyte-menu-list", null, this.canDisableParticipantAudio && (h("dyte-menu-item", { onClick: () => {
        this.meeting.participants.disableAudio(this.peer.id);
      } }, h("dyte-icon", { icon: this.iconPack.mic_off, slot: "start" }), "Mute")), this.canDisableParticipantAudio && (h("dyte-menu-item", { onClick: () => {
        this.meeting.participants.disableVideo(this.peer.id);
      } }, h("dyte-icon", { icon: this.iconPack.video_off, slot: "start" }), "Turn off Video")), this.canKickParticipant && (h("dyte-menu-item", { class: "red", onClick: () => {
        this.meeting.participants.kick(this.peer.id);
      } }, h("dyte-icon", { icon: this.iconPack.dismiss, slot: "start" }), "Kick"))))))));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"],
    "peer": ["peerChanged"]
  }; }
  static get style() { return dyteParticipantCss; }
}, [1, "dyte-participant", {
    "meeting": [16],
    "peer": [16],
    "iconPack": [16],
    "t": [16],
    "audioEnabled": [32],
    "videoEnabled": [32],
    "canDisableParticipantAudio": [32],
    "canDisableParticipantVideo": [32],
    "canKickParticipant": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-participant", "dyte-avatar", "dyte-button", "dyte-icon", "dyte-menu", "dyte-menu-item", "dyte-menu-list"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-participant":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteParticipant);
      }
      break;
    case "dyte-avatar":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "dyte-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "dyte-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "dyte-menu":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "dyte-menu-item":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "dyte-menu-list":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { DyteParticipant as D, defineCustomElement as d };
