import { proxyCustomElement, HTMLElement, createEvent, writeTask, h, Host } from '@stencil/core/internal/client';
import { d as defaultIconPack } from './default-icon-pack.js';
import { u as useLanguage } from './index2.js';
import { a as getPreference, s as setPreference } from './user-prefs.js';
import { d as defineCustomElement$2 } from './dyte-button2.js';
import { d as defineCustomElement$1 } from './dyte-peer-view2.js';

const dyteSettingsVideoCss = ".dyte-select{-webkit-appearance:none;-moz-appearance:none;appearance:none;background-color:#fff;border-color:#6b7280;border-width:1px;border-radius:0px;padding-top:0.5rem;padding-right:0.75rem;padding-bottom:0.5rem;padding-left:0.75rem;font-size:1rem;line-height:1.5rem;--tw-shadow:0 0 #0000}.dyte-select:focus{outline:2px solid transparent;outline-offset:2px;--tw-ring-inset:var(--tw-empty, );--tw-ring-offset-width:0px;--tw-ring-offset-color:#fff;--tw-ring-color:#2563eb;--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow);border-color:#2563eb}.dyte-select{background-image:url(\"data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 20 20'%3e%3cpath stroke='%236b7280' stroke-linecap='round' stroke-linejoin='round' stroke-width='1.5' d='M6 8l4 4 4-4'/%3e%3c/svg%3e\");background-position:right 0.5rem center;background-repeat:no-repeat;background-size:1.5em 1.5em;padding-right:2.5rem;-webkit-print-color-adjust:exact;color-adjust:exact;display:block;border-radius:var(--dyte-border-radius-sm, 4px);border-width:var(--dyte-border-width-none, 0);border-style:none;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-700, 44 44 44) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-1000, 255 255 255))}.dyte-select:focus{--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(0px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow, 0 0 #0000)}:host{display:flex;width:100%;flex-direction:column;font-family:var(--dyte-font-family, sans-serif)}dyte-peer-view{margin-left:auto;margin-right:auto;margin-bottom:var(--dyte-space-4, 16px);max-width:100%}.apply-button{margin-left:var(--dyte-space-2, 8px);padding-top:var(--dyte-space-5, 20px);padding-bottom:var(--dyte-space-5, 20px)}label{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;font-size:14px}.group{margin-top:var(--dyte-space-2, 8px);margin-bottom:var(--dyte-space-2, 8px)}.group>*{margin-bottom:var(--dyte-space-2, 8px)}.group>*:last-child{margin-bottom:var(--dyte-space-0, 0px)}.group select{flex:1 1 0%}.row{display:flex;align-items:center;justify-content:space-between}";

const DyteSettingsVideo = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.stateUpdate = createEvent(this, "dyteStateUpdate", 7);
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.videoDevices = [];
  }
  componentDidLoad() {
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    var _a;
    (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.disablePreview({ video: true });
  }
  meetingChanged(meeting) {
    if (meeting == null)
      return;
    writeTask(async () => {
      await meeting.self.enablePreview({ video: true });
      this.videoDevices = meeting.self.getVideoDevices();
    });
  }
  async setDevice(deviceId) {
    var _a, _b;
    const device = this.videoDevices.find((d) => d.deviceId === deviceId);
    this.currentDevice = device;
    if (device != null) {
      await ((_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.setDevice(device, true));
      await ((_b = this.meeting) === null || _b === void 0 ? void 0 : _b.self.enablePreview({ video: true }));
    }
  }
  async onApply() {
    var _a, _b;
    if (this.currentDevice != null) {
      await ((_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.setDevice(this.currentDevice));
      await ((_b = this.meeting) === null || _b === void 0 ? void 0 : _b.self.enablePreview({ video: true }));
    }
  }
  render() {
    var _a;
    if (this.meeting == null)
      return null;
    let unnamedVideoCount = 0;
    const initialMirrorPreference = ((_a = this.states.prefs) === null || _a === void 0 ? void 0 : _a.mirrorVideo) || getPreference('mirror-video') === 'true';
    return (h(Host, null, h("div", { class: "group" }, h("dyte-peer-view", { peer: this.meeting.self, states: this.states, isPreview: true })), h("div", { class: "group" }, h("label", null, "Camera"), h("div", { class: "row" }, h("select", { class: "dyte-select", onChange: (e) => this.setDevice(e.target.value) }, this.videoDevices.map(({ deviceId, label }) => (h("option", { value: deviceId }, label || `Camera ${++unnamedVideoCount}`)))), h("dyte-button", { class: "apply-button", onClick: () => this.onApply() }, "Apply"))), h("div", { class: "group" }, h("div", { class: "row" }, h("label", { htmlFor: "mirror-toggle" }, "Mirror my Video"), h("input", { type: "checkbox", id: "mirror-toggle", defaultChecked: initialMirrorPreference, onChange: (e) => {
        const { checked } = e.target;
        this.stateUpdate.emit({ prefs: { mirrorVideo: checked } });
        setPreference('mirror-video', checked);
      } })))));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
  static get style() { return dyteSettingsVideoCss; }
}, [1, "dyte-settings-video", {
    "meeting": [16],
    "states": [16],
    "size": [513],
    "iconPack": [16],
    "t": [16],
    "videoDevices": [32],
    "currentDevice": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-settings-video", "dyte-button", "dyte-peer-view"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-settings-video":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteSettingsVideo);
      }
      break;
    case "dyte-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "dyte-peer-view":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { DyteSettingsVideo as D, defineCustomElement as d };
