import { r as registerInstance, h, H as Host, c as createEvent, g as getElement } from './index-da7bf46b.js';
import { d as defaultIconPack } from './default-icon-pack-3c344d0e.js';
import { u as useLanguage, g as getLangData } from './index-a651ed73.js';
import { d as downloadFile } from './file-1dcac04e.js';
import { f as formatName, s as shorten } from './string-739d5cc6.js';
import { d as defaultConfig, R as Render } from './index-560ccbe9.js';
import { p as provideDyteDesignSystem } from './provide-design-system-ffb9bfd1.js';
import { g as getUserPreferences } from './user-prefs-296aaa37.js';
import './graceful-storage-33bc316d.js';

const dyteButtonCss = ":host{position:relative;box-sizing:border-box;display:inline-flex;height:var(--dyte-space-8, 32px);flex-direction:column;padding-left:var(--dyte-space-3, 12px);padding-right:var(--dyte-space-3, 12px);font-family:var(--dyte-font-family, sans-serif);border-radius:var(--dyte-border-radius-md, 8px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-brand-500, 33 96 253) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-1000, 255 255 255));--tw-shadow:0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 4px 6px -1px var(--tw-shadow-color), 0 2px 4px -2px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;font-size:16px;transition-property:color, background-color, border-color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-text-decoration-color, -webkit-backdrop-filter;transition-property:color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property:color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-text-decoration-color, -webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms;cursor:pointer}:host(:hover),:host(:focus){--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-brand-700, 2 70 253) / var(--tw-bg-opacity))}button{display:inline-flex;flex:1 1 0%;align-items:center;justify-content:center;height:100%;width:100%;border-width:var(--dyte-border-width-none, 0);border-style:none;outline:2px solid transparent;outline-offset:2px;background-color:transparent;color:inherit;border-radius:inherit;fill:inherit;cursor:inherit;font-family:inherit;font-size:inherit;line-height:inherit}::slotted(dyte-icon){height:var(--dyte-space-6, 24px);width:var(--dyte-space-6, 24px)}::slotted(dyte-icon[slot='start']){margin-right:var(--dyte-space-1, 4px)}:host([kind='icon']){height:var(--dyte-space-8, 32px);width:var(--dyte-space-8, 32px);padding:var(--dyte-space-0, 0px)}:host([disabled]){cursor:not-allowed;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-600, 60 60 60) / var(--tw-bg-opacity))}:host([variant='outline']){--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-1000, 8 8 8) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-700, 255 255 255 / 0.64));border:var(--dyte-border-width-sm, 1px) solid rgb(var(--dyte-colors-background-600, 60 60 60))}:host([variant='neutral']){border-radius:var(--dyte-border-radius-none, 0);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-1000, 8 8 8) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-700, 255 255 255 / 0.64))}:host([variant='ghost']){background-color:transparent;color:rgb(var(--dyte-colors-text-600, 255 255 255 / 0.52));box-shadow:none}:host([variant='ghost']:hover),:host([variant='ghost']:focus){--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-700, 44 44 44) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-1000, 255 255 255))}";

const DyteButton = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /** Button variant */
    this.variant = 'accent';
    /** Button type */
    this.kind = 'button';
    /** Whether to reverse order of children */
    this.reverse = false;
    /** Where the button is disabled or not */
    this.disabled = false;
  }
  render() {
    return (h(Host, null, h("button", { part: "button" }, h("slot", { name: "start" }), h("slot", null), h("slot", { name: "end" }))));
  }
};
DyteButton.style = dyteButtonCss;

const dyteIconCss = ":host{display:block;height:var(--dyte-space-10, 40px);font-family:var(--dyte-font-family, sans-serif)}:host .icon-wrapper{display:flex;height:100%;width:100%;flex-direction:column;align-items:center}:host svg{height:100%;width:100%}";

const parseIcon = (icon) => {
  try {
    return JSON.parse(icon);
  }
  catch (e) {
    return icon;
  }
};
const DyteIcon = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
  }
  render() {
    return (h(Host, null, h("div", { class: "icon-wrapper", innerHTML: parseIcon(this.icon) })));
  }
};
DyteIcon.style = dyteIconCss;

const getIconPack = async (url) => {
  // check for both null/undefined
  if (url == null) {
    return defaultIconPack;
  }
  try {
    const res = await fetch(url);
    if (!res.ok) {
      return defaultIconPack;
    }
    // merge defaultIconPack with the received iconPack so as to
    // fill the missing icons with default ones
    return Object.assign({}, defaultIconPack, await res.json());
  }
  catch (_) {
    return defaultIconPack;
  }
};

const dyteImageViewerCss = ".scrollbar{scrollbar-width:thin;scrollbar-color:var(--dyte-scrollbar-color, rgb(var(--dyte-colors-background-600, 60 60 60)))\n    var(--dyte-scrollbar-background, transparent)}.scrollbar::-webkit-scrollbar{height:var(--dyte-space-1\\.5, 6px);width:var(--dyte-space-1\\.5, 6px);border-radius:9999px;background-color:var(--dyte-scrollbar-background, transparent)}.scrollbar::-webkit-scrollbar-thumb{border-radius:9999px;background-color:var(--dyte-scrollbar-color, rgb(var(--dyte-colors-background-600, 60 60 60)))}:host{position:fixed;top:var(--dyte-space-0, 0px);right:var(--dyte-space-0, 0px);bottom:var(--dyte-space-0, 0px);left:var(--dyte-space-0, 0px);box-sizing:border-box;display:flex;align-items:center;justify-content:center;padding:var(--dyte-space-6, 24px);overflow-y:auto;background-color:rgba(var(--dyte-colors-background-1000, 8 8 8) / 0.8);z-index:40}.modal{box-sizing:border-box;display:flex;flex-direction:column;padding:var(--dyte-space-6, 24px);padding-top:var(--dyte-space-5, 20px);width:100%;max-width:940px;border-radius:var(--dyte-border-radius-md, 8px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-900, 26 26 26) / var(--tw-bg-opacity));margin-top:auto;margin-bottom:auto}.displayName{font-weight:700}.modal .image-ctr{margin-top:var(--dyte-space-2, 8px);box-sizing:border-box;display:flex;justify-content:center}.modal img{box-sizing:border-box;display:block;max-height:100%;max-width:100%}.modal-header{display:flex;align-items:center;justify-content:space-between;padding-bottom:var(--dyte-space-4, 16px)}dyte-button{height:var(--dyte-space-8, 32px);border-radius:var(--dyte-border-radius-sm, 4px)}dyte-button:last-child{margin-left:var(--dyte-space-2, 8px)}dyte-button{font-size:14px}dyte-button dyte-icon{width:var(--dyte-space-5, 20px)}.shared-by-user{overflow:hidden;display:-webkit-box;-webkit-box-orient:vertical;-webkit-line-clamp:1}:host([size='sm']) .modal-header{flex-direction:column}:host([size='sm']) .modal-header .actions{margin-top:var(--dyte-space-4, 16px)}";

const DyteImageViewer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.close = createEvent(this, "close", 7);
    /** Language */
    this.t = useLanguage();
    /** Icon pack */
    this.iconPack = defaultIconPack;
    this.keypressListener = (e) => {
      if (e.key === 'Escape') {
        this.close.emit();
      }
    };
    this.handleOutsideClick = () => this.close.emit();
  }
  connectedCallback() {
    document.addEventListener('keydown', this.keypressListener);
    document.addEventListener('click', this.handleOutsideClick);
  }
  disconnectedCallback() {
    document.removeEventListener('keydown', this.keypressListener);
    document.removeEventListener('click', this.handleOutsideClick);
  }
  render() {
    return (h(Host, { class: "scrollbar" }, h("div", { class: "modal", onClick: (e) => e.stopPropagation() }, h("div", { class: "modal-header" }, h("div", { class: "shared-by-user" }, this.t('Shared by'), ' ', h("span", { class: "displayName" }, formatName(shorten(this.image.displayName)))), h("div", { class: "actions" }, h("dyte-button", { kind: "icon", variant: "neutral", onClick: () => this.close.emit() }, h("dyte-icon", { icon: this.iconPack.arrow_minimize })), h("dyte-button", { onClick: () => downloadFile(this.image.link, { fallbackName: 'image' }) }, h("dyte-icon", { icon: this.iconPack.download, slot: "start" }), "Download"))), h("div", { class: "image-ctr" }, h("img", { src: this.image.link })))));
  }
};
DyteImageViewer.style = dyteImageViewerCss;

const sm = 700;
const md = 1280;
const lg = 1920;
const xl = 2160;
const breakpoints = {
	sm: sm,
	md: md,
	lg: lg,
	xl: xl
};

/**
 * Get the screen breakpoint from a given width
 * @param width The width of the container
 * @returns The screen breakpoint value
 */
const getSize = (width) => {
  if (width < breakpoints.sm)
    return 'sm';
  else if (width < breakpoints.md)
    return 'md';
  else if (width < breakpoints.lg)
    return 'lg';
  return 'xl';
};

const dyteMeetingCss = ":host{position:relative;box-sizing:border-box;display:block;height:100%;width:100%;font-family:var(--dyte-font-family, sans-serif);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-1000, 8 8 8) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-900, 255 255 255 / 0.88));overflow:hidden}";

const DyteMeeting = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.roomJoinedListener = () => {
      this.setStates({ meeting: 'joined' });
    };
    this.roomLeftListener = ({ state }) => {
      if (this.states.roomLeftState === 'disconnected') {
        this.setStates({ meeting: 'ended' });
        return;
      }
      this.setStates({ meeting: 'ended', roomLeftState: state });
    };
    /** Where to show setup screen or not */
    this.showSetupScreen = true;
    /** Language */
    this.language = 'en';
    /** UI Config */
    this.config = defaultConfig;
    this.states = {
      meeting: 'idle',
      prefs: {
        mirrorVideo: true,
        muteNotificationSounds: false,
      },
    };
    this.iconPack = defaultIconPack;
    this.t = useLanguage();
  }
  connectedCallback() {
    this.resizeObserver = new ResizeObserver(() => this.handleResize());
    this.resizeObserver.observe(this.host);
    if (typeof this.config.designTokens !== 'undefined') {
      provideDyteDesignSystem(this.host, this.config.designTokens);
    }
    this.meetingChanged(this.meeting);
    this.iconPackUrlChanged(this.iconPackUrl);
    this.languageChanged(this.language);
    this.initializePreferences();
  }
  disconnectedCallback() {
    var _a, _b;
    this.resizeObserver.disconnect();
    this.roomJoinedListener &&
      ((_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.removeListener('roomJoined', this.roomJoinedListener));
    this.roomLeftListener && ((_b = this.meeting) === null || _b === void 0 ? void 0 : _b.self.removeListener('roomLeft', this.roomLeftListener));
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      if (this.showSetupScreen) {
        this.states = Object.assign(Object.assign({}, this.states), { meeting: 'setup' });
      }
      meeting.self.addListener('roomJoined', this.roomJoinedListener);
      meeting.self.addListener('roomLeft', this.roomLeftListener);
      if (!this.showSetupScreen) {
        // join directly to the meeting
        meeting.joinRoom();
      }
    }
  }
  async iconPackUrlChanged(url) {
    this.iconPack = await getIconPack(url);
  }
  async languageChanged(lang) {
    this.t = useLanguage(await getLangData(lang));
  }
  listenState(e) {
    e.stopPropagation();
    this.setStates(e.detail);
  }
  listenViewImage(e) {
    this.image = e.detail;
  }
  initializePreferences() {
    const prefs = getUserPreferences();
    this.setStates({ prefs });
  }
  handleResize() {
    this.size = getSize(this.host.clientWidth);
  }
  setStates(states) {
    this.states = Object.assign(Object.assign({}, this.states), states);
  }
  render() {
    const defaults = {
      meeting: this.meeting,
      size: this.size,
      states: this.states,
      config: this.config,
      iconPack: this.iconPack,
      t: this.t,
    };
    return (h(Render, { element: "dyte-meeting", defaults: defaults, asHost: true }, this.image && (h("dyte-image-viewer", Object.assign({}, defaults, { image: this.image, onClose: () => (this.image = null) })))));
  }
  get host() { return getElement(this); }
  static get watchers() { return {
    "meeting": ["meetingChanged"],
    "iconPackUrl": ["iconPackUrlChanged"],
    "language": ["languageChanged"]
  }; }
};
DyteMeeting.style = dyteMeetingCss;

export { DyteButton as dyte_button, DyteIcon as dyte_icon, DyteImageViewer as dyte_image_viewer, DyteMeeting as dyte_meeting };
