import { r as registerInstance, h, H as Host } from './index-da7bf46b.js';
import { d as defaultIconPack } from './default-icon-pack-3c344d0e.js';
import { u as useLanguage } from './index-a651ed73.js';

const dyteCameraToggleCss = ":host{display:block;font-family:var(--dyte-font-family, sans-serif)}";

const DyteCameraToggle = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.videoEnabled = false;
    this.canProduceVideo = false;
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    var _a;
    this.videoUpdateListener &&
      ((_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.removeListener('videoUpdate', this.videoUpdateListener));
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      const self = meeting.self;
      this.canProduceVideo = self.permissions.produceVideo.allow;
      this.videoEnabled = self.videoEnabled;
      this.videoUpdateListener = ({ videoEnabled }) => {
        this.videoEnabled = videoEnabled;
      };
      self.addListener('videoUpdate', this.videoUpdateListener);
    }
  }
  toggleCamera() {
    var _a;
    const self = (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self;
    if (self == null || !this.canProduceVideo) {
      return;
    }
    if (self.videoEnabled) {
      self.disableVideo();
    }
    else {
      self.enableVideo();
    }
  }
  render() {
    if (!this.canProduceVideo) {
      return null;
    }
    const text = this.t(this.videoEnabled ? 'video_on' : 'video_off');
    return (h(Host, { title: text }, h("dyte-controlbar-button", { size: this.size, class: {
        'red-icon': !this.videoEnabled,
      }, onClick: () => this.toggleCamera(), icon: this.videoEnabled ? this.iconPack.video_on : this.iconPack.video_off, label: text })));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
};
DyteCameraToggle.style = dyteCameraToggleCss;

const dyteMicToggleCss = ":host{display:block;font-family:var(--dyte-font-family, sans-serif)}:host(.audioDisabled) :slotted(dyte-icon){--tw-text-opacity:1;color:rgba(var(--dyte-colors-danger, 255 45 45) / var(--tw-text-opacity))}";

const DyteMicToggle = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.audioEnabled = false;
    this.canProduceAudio = false;
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    var _a;
    this.audioUpdateListener &&
      ((_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.removeListener('audioUpdate', this.audioUpdateListener));
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      const self = meeting.self;
      this.canProduceAudio = self.permissions.produceAudio;
      this.audioEnabled = self.audioEnabled;
      this.audioUpdateListener = ({ audioEnabled }) => {
        this.audioEnabled = audioEnabled;
      };
      self.addListener('audioUpdate', this.audioUpdateListener);
    }
  }
  toggleMic() {
    var _a;
    const self = (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self;
    if (self == null || !this.canProduceAudio) {
      return;
    }
    if (self.audioEnabled) {
      self.disableAudio();
    }
    else {
      self.enableAudio();
    }
  }
  render() {
    if (!this.canProduceAudio) {
      return null;
    }
    const text = this.t(this.audioEnabled ? 'mic_on' : 'mic_off');
    return (h(Host, { title: text }, h("dyte-controlbar-button", { size: this.size, class: {
        'red-icon': !this.audioEnabled,
      }, onClick: () => this.toggleMic(), icon: this.audioEnabled ? this.iconPack.mic_on : this.iconPack.mic_off, label: text })));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
};
DyteMicToggle.style = dyteMicToggleCss;

export { DyteCameraToggle as dyte_camera_toggle, DyteMicToggle as dyte_mic_toggle };
