import { r as registerInstance, h, H as Host } from './index-da7bf46b.js';
import { d as defaultIconPack } from './default-icon-pack-3c344d0e.js';
import { u as useLanguage } from './index-a651ed73.js';

const dyteParticipantCountCss = ":host{display:inline-flex;height:var(--dyte-space-10, 40px);width:var(--dyte-space-10, 40px);align-items:center;padding:var(--dyte-space-1, 4px);font-family:var(--dyte-font-family, sans-serif)}dyte-icon{margin-right:var(--dyte-space-1, 4px);height:60%;width:auto}";

const DyteParticipantCount = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.participantCount = 0;
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    if (this.meeting != null && this.countListener != null) {
      this.meeting.participants.joined.removeListener('participantJoined', this.countListener);
      this.meeting.participants.joined.removeListener('participantLeft', this.countListener);
    }
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.countListener = () => {
        this.participantCount = meeting.participants.joined.size + (meeting.meta.joined ? 1 : 0);
      };
      this.countListener();
      meeting.participants.joined.addListener('participantJoined', this.countListener);
      meeting.participants.joined.addListener('participantLeft', this.countListener);
    }
  }
  render() {
    return (h(Host, { tabIndex: 0, role: "log", "aria-label": `${this.participantCount} ${this.t('participants')}` }, h("dyte-icon", { icon: this.iconPack.people, tabIndex: -1, "aria-hidden": true }), this.participantCount));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
};
DyteParticipantCount.style = dyteParticipantCountCss;

export { DyteParticipantCount as dyte_participant_count };
