import { r as registerInstance, c as createEvent, h, H as Host } from './index-da7bf46b.js';
import { d as defaultIconPack } from './default-icon-pack-3c344d0e.js';
import { u as useLanguage } from './index-a651ed73.js';

const dytePluginsToggleCss = ":host{display:block}";

const DytePluginsToggle = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.stateUpdate = createEvent(this, "dyteStateUpdate", 7);
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.pluginsActive = false;
  }
  connectedCallback() {
    this.statesChanged(this.states);
  }
  statesChanged(states) {
    if (states != null) {
      this.pluginsActive = this.states.activeSidebar && this.states.sidebar === 'plugins';
    }
  }
  togglePlugins() {
    this.pluginsActive = !(this.states.activeSidebar && this.states.sidebar === 'plugins');
    this.stateUpdate.emit({
      activeSidebar: this.pluginsActive,
      sidebar: this.pluginsActive ? 'plugins' : 'none',
    });
  }
  render() {
    const text = this.t('plugins');
    return (h(Host, { title: text }, h("dyte-controlbar-button", { class: { active: this.pluginsActive }, size: this.size, onClick: () => this.togglePlugins(), icon: this.iconPack.rocket, label: text })));
  }
  static get watchers() { return {
    "states": ["statesChanged"]
  }; }
};
DytePluginsToggle.style = dytePluginsToggleCss;

export { DytePluginsToggle as dyte_plugins_toggle };
