import { r as registerInstance, c as createEvent, h, H as Host } from './index-da7bf46b.js';
import { d as defaultIconPack } from './default-icon-pack-3c344d0e.js';
import { u as useLanguage } from './index-a651ed73.js';

const dyteSidebarCss = ":host{position:relative;box-sizing:border-box;display:block;width:100%;max-width:var(--dyte-space-80, 320px);overflow:hidden;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-1000, 8 8 8) / var(--tw-bg-opacity));display:flex;flex-direction:column}.close{display:none;position:absolute;top:var(--dyte-space-3, 12px);left:var(--dyte-space-3, 12px);height:var(--dyte-space-6, 24px);width:var(--dyte-space-6, 24px);cursor:pointer;color:rgb(var(--dyte-colors-text-900, 255 255 255 / 0.88))}.title{margin:var(--dyte-space-0, 0px);margin-top:var(--dyte-space-3, 12px);margin-bottom:var(--dyte-space-3, 12px);-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;text-align:center;font-size:16px;font-weight:400}#mobile-header{margin-top:var(--dyte-space-2, 8px);display:flex;align-items:center;justify-content:space-evenly;border-bottom:var(--dyte-border-width-sm, 1px) solid rgb(var(--dyte-colors-background-600, 60 60 60))}#mobile-header dyte-button{height:var(--dyte-space-10, 40px);font-size:14px;color:rgb(var(--dyte-colors-text-800, 255 255 255 / 0.76));border-bottom:var(--dyte-border-width-md, 2px) solid transparent}#mobile-header dyte-button.active{--tw-text-opacity:1;color:rgba(var(--dyte-colors-brand-400, 53 110 253) / var(--tw-text-opacity));border-color:rgb(var(--dyte-colors-brand-400, 53 110 253))}dyte-chat,dyte-participants,dyte-plugins{flex:1}:host([view='sidebar']){margin-left:var(--dyte-space-2, 8px);margin-right:var(--dyte-space-2, 8px);border-radius:var(--dyte-border-radius-lg, 12px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-900, 26 26 26) / var(--tw-bg-opacity))}:host([view='sidebar']) .close{display:inline-flex}:host([view='full-screen']){position:absolute;top:var(--dyte-space-0, 0px);right:var(--dyte-space-0, 0px);bottom:var(--dyte-space-0, 0px);left:var(--dyte-space-0, 0px);z-index:30;max-width:100%;border:none}:host([view='full-screen']) .close{display:block}";

const DyteSidebar = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.stateUpdate = createEvent(this, "dyteStateUpdate", 7);
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    /** View type */
    this.view = 'default';
    this.tab = 'none';
  }
  connectedCallback() {
    this.viewChanged(this.view);
    this.statesChanged(this.states);
  }
  disconnectedCallback() {
    this.keydownListener && document.removeEventListener('keydown', this.keydownListener);
  }
  statesChanged(states) {
    if (states != null) {
      if (states.sidebar) {
        this.tab = states.sidebar;
      }
    }
  }
  viewChanged(view) {
    if (view === 'full-screen') {
      this.keydownListener = (e) => {
        if (e.key === 'Escape') {
          this.close();
        }
      };
      document.addEventListener('keydown', this.keydownListener);
    }
  }
  close() {
    this.stateUpdate.emit({ activeSidebar: false, sidebar: 'none' });
  }
  render() {
    const defaults = { meeting: this.meeting, size: this.size, config: this.config };
    return (h(Host, { style: { display: this.tab === 'none' ? 'none' : undefined } }, this.view === 'full-screen' && [
      h("h3", { class: "title" }, this.t('About Call')),
      h("div", { id: "mobile-header" }, h("dyte-button", { variant: "neutral", class: { active: this.tab === 'chat' }, onClick: () => {
          this.stateUpdate.emit({ sidebar: 'chat' });
        } }, "Chat"), h("dyte-button", { variant: "neutral", class: { active: this.tab === 'participants' }, onClick: () => {
          this.stateUpdate.emit({ sidebar: 'participants' });
        } }, "Participants"), h("dyte-button", { variant: "neutral", class: { active: this.tab === 'plugins' }, onClick: () => {
          this.stateUpdate.emit({ sidebar: 'plugins' });
        } }, "Plugins")),
    ], h("dyte-button", { variant: "ghost", kind: "icon", class: "close", onClick: () => this.close(), "aria-label": this.t('Close') }, h("dyte-icon", { icon: this.iconPack.dismiss })), this.view !== 'full-screen' && h("h3", { class: "title" }, this.t(this.tab)), this.tab === 'chat' && h("dyte-chat", Object.assign({}, defaults)), this.tab === 'participants' && h("dyte-participants", Object.assign({}, defaults)), this.tab === 'plugins' && h("dyte-plugins", Object.assign({}, defaults))));
  }
  static get watchers() { return {
    "states": ["statesChanged"],
    "view": ["viewChanged"]
  }; }
};
DyteSidebar.style = dyteSidebarCss;

export { DyteSidebar as dyte_sidebar };
