/// <reference types="node" />
import { EventEmitter } from 'events';
export declare enum MediaEvents {
    AUDIO_TRACK_CHANGE = 0,
    VIDEO_TRACK_CHANGE = 1,
    SCREENSHARE_TRACK_CHANGE = 2,
    SCREENSHARE_ENDED = 3
}
export declare type MediaPermission = 'ACCEPTED' | 'DENIED' | 'SYS_DENIED' | 'UNAVAILABLE' | 'NOT_REQUESTED';
export default class LocalMediaHandler extends EventEmitter {
    #private;
    audioTrack: MediaStreamTrack;
    videoTrack: MediaStreamTrack;
    screenShareTracks: {
        audio?: MediaStreamTrack;
        video?: MediaStreamTrack;
    };
    audioEnabled: boolean;
    videoEnabled: boolean;
    screenShareEnabled: boolean;
    currentDevices: {
        audio: MediaDeviceInfo;
        video: MediaDeviceInfo;
        speaker: MediaDeviceInfo;
    };
    permissions: {
        audio?: MediaPermission;
        video?: MediaPermission;
    };
    private constructor();
    private handlePermissionErrors;
    private onVisibilityChange;
    private conditionallyRestartAudio;
    private conditionallyRestartVideo;
    private shouldReacquireTrack;
    private onAudioUnmute;
    private onVideoUnmute;
    private removeMediaStreamTrackListeners;
    private addMediaStreamTrackListeners;
    setupAudioStream(deviceId?: string, forceStopTrack?: boolean): Promise<void>;
    setupVideoStream(deviceId?: string, forceStopTrack?: boolean): Promise<void>;
    setupSpeaker(deviceId?: string): Promise<void>;
    getOperationalWebcamDeviceId(): Promise<{
        isOperational: boolean;
        deviceId: string;
    }>;
    getOperationalMicDeviceId(): Promise<{
        isOperational: boolean;
        deviceId: string;
    }>;
    setupStreams({ audio, video }: {
        audio: boolean;
        video: boolean;
    }): Promise<void>;
    private stopAudioTrack;
    private stopVideoTrack;
    private stopScreenShareTracks;
    removeAudioTrack(): void;
    removeVideoTrack(): void;
    removeScreenShareTracks(tracks?: {
        audio?: boolean;
        video?: boolean;
    }): void;
    removeAllTracks(): void;
    private setAudioTrack;
    private setVideoTrack;
    private setScreenShareTracks;
    private onScreenShareEnded;
    toggleAudio(): Promise<void>;
    toggleVideo(): Promise<void>;
    toggleScreenShare(): Promise<void>;
    getAllDevices(): MediaDeviceInfo[];
    getDeviceById(deviceId: string, kind: 'audioinput' | 'audiooutput' | 'videoinput'): MediaDeviceInfo;
    getAudioDevices(): MediaDeviceInfo[];
    getVideoDevices(): MediaDeviceInfo[];
    getSpeakerDevices(): MediaDeviceInfo[];
    onDeviceChange(ev: Event, changedDevices: {
        added: MediaDeviceInfo[];
        removed: MediaDeviceInfo[];
    }): Promise<void>;
    onPermissionChange(): Promise<void>;
    static init(): Promise<LocalMediaHandler>;
    emit(event: keyof typeof MediaEvents, ...args: any[]): boolean;
    on(event: keyof typeof MediaEvents, listener: (...args: any[]) => void): this;
}
