import { Tracer } from '@opentelemetry/sdk-trace-base';
import { Span } from '@opentelemetry/api';
export default class DyteTelemetry {
    static tracer: Tracer;
    static rootSpan: Span;
    static meetingMetadata: {
        peerId?: string;
        roomName?: string;
        organizationId?: string;
        sdkVersion?: string;
        deviceInfo?: object;
    };
    static init(peerId: string): void;
    static trace(spanName: string): (_target: Object, _propertyKey: string, descriptor: PropertyDescriptor) => PropertyDescriptor;
    static getCurrentSpan(): Span;
    static getCurrentSpanName(): any;
    /**
     * Adds event into the current span or the main span.
     * Event(or this method) is not a replacement for a log.
     * Tip :: Heavy objects should be logged.
     * Tip :: Light objects with `to the point` info should be added as events.
     * @param eventSeverity severity of the passed event to create better dashboards
     * @param eventName name of event in format
     *  fileName::functionName::eventName or functionName::eventName or whatever seems fit
     * @param metadata pass any information which makes sense for analytics or debugging
     * @returns nothing
     */
    static addEventInCurrentSpan(eventSeverity: 'info' | 'error' | 'debug' | 'log' | 'warn', eventName: string, metadata?: {
        [key: string]: any;
    }): void;
    static sendOtelLogToNewRelic(logSeverity: 'info' | 'error' | 'debug' | 'log' | 'warn', message: string, metadata?: {
        [key: string]: any;
    }): void;
}
